diff --git a/src/THcDetectorMap.cxx b/src/THcDetectorMap.cxx
index 76141676e1013d2d67829d58333ee7282faccae4..7cb72aa8793aa743d491c46666cfc2116fce2fae 100644
--- a/src/THcDetectorMap.cxx
+++ b/src/THcDetectorMap.cxx
@@ -42,9 +42,9 @@ THcDetectorMap::~THcDetectorMap()
 {
 }
 
-//bool THcDetectorMap::compare(const ChaninMod *first, const ChaninMod *second) {
-//      return((first->channel < second->channel)? true: false);
-//}
+bool THcDetectorMap::compare(const ChaninMod *first, const ChaninMod *second) {
+      return((first->channel < second->channel)? true: false);
+}
 struct Functor
 {
   bool operator() (const THcDetectorMap::ChaninMod &first, const THcDetectorMap::ChaninMod &second)
diff --git a/src/THcHodoscope.cxx b/src/THcHodoscope.cxx
index 221dab60bccb6f0a166106a30d8732f44a1cffab..1fc80f6533f51b4121ac6e1b9862f30dc26c7b77 100644
--- a/src/THcHodoscope.cxx
+++ b/src/THcHodoscope.cxx
@@ -10,6 +10,8 @@
 #include "THcHodoscope.h"
 #include "THaEvData.h"
 #include "THaDetMap.h"
+#include "THcDetectorMap.h"
+#include "THcGlobals.h"
 #include "VarDef.h"
 #include "VarType.h"
 #include "THaTrack.h"
@@ -69,7 +71,7 @@ THaAnalysisObject::EStatus THcHodoscope::Init( const TDatime& date )
   // maximum number of hits after setting up the detector map
 
   THcHitList::InitHitList(fDetMap, "THcHodoscopeHit", 100);
-  if( gHcDetectorMap->FillMap("detectorname",fDetMap) < 0 ) {
+  if( gHcDetectorMap->FillMap(fDetMap, "detectorname") < 0 ) {
       Error( Here(here), "Error filling detectormap for %s.", 
 	     "detectorname");
       return kInitError;
diff --git a/src/THcGlobals.h b/src/THcGlobals.h
index 39b40da8de54367c2f2ebeebb2337e34d6df90ad..c18bf53ac1c721bb8023bed65cbc4f9bd51abb54 100644
--- a/src/THcGlobals.h
+++ b/src/THcGlobals.h
@@ -6,8 +6,9 @@
 #include "DllImport.h"
 #endif
 
 // Global Analyzer variables. Defined in THaInterface implementation file.
 
 R__EXTERN class THcParmList*  gHcParms;      //List of global symbolic variables
+R__EXTERN class THcDetectorMap*  gHcDetectorMap;   //Cached map file
 
 #endif
@@ -6,8 +6,9 @@
 #endif
 
-// Global Analyzer variables. Defined in THaInterface implementation file.
+// Global Analyzer variables. Defined in THcInterface implementation file.
 
 R__EXTERN class THcParmList*  gHcParms;      //List of global symbolic variables